@@ -3,9 +3,6 @@ package Image::BoxModel::Backend::IM;
 use strict;
 use warnings;
 
-use Image::BoxModel::Lowlevel;
-our @ISA = ("Image::BoxModel::Lowlevel");
-
 sub DrawRectangle{
 	my $image = shift;
 	my %p = @_;
@@ -143,6 +140,8 @@ sub DrawText{
 	return $warning;
 }
 
+
+
 sub Save{
 	my $image = shift;
 	my %p = @_;
